#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hosc
version:              0.19
visibility:           public
id:                   hosc-0.19-9E4zMGa8TwZKXIyTOOXEfd
key:                  hosc-0.19-9E4zMGa8TwZKXIyTOOXEfd
license:              GPL-3.0-only
copyright:            (c) Rohan Drape, Stefan Kersten and others, 2007-2021
maintainer:           rd@rohandrape.net
author:               Rohan Drape, Stefan Kersten
stability:            Experimental
homepage:             http://rohandrape.net/t/hosc
synopsis:             Haskell Open Sound Control
description:
    @hosc@ implements a subset of the Open Sound Control
    byte protocol, <http://opensoundcontrol.org/>.

    See "Sound.OSC.Core" or "Sound.OSC" or "Sound.OSC.FD".

category:             Sound
abi:                  bd448defb057ed2a024754c4a8c7b45f
exposed:              True
exposed-modules:
    Sound.OSC Sound.OSC.Coding.Byte Sound.OSC.Coding.Cast
    Sound.OSC.Coding.Convert Sound.OSC.Coding.Decode.Base
    Sound.OSC.Coding.Decode.Binary Sound.OSC.Coding.Encode.Base
    Sound.OSC.Coding.Encode.Builder Sound.OSC.Core Sound.OSC.Datum
    Sound.OSC.FD Sound.OSC.Packet Sound.OSC.Time Sound.OSC.Transport.FD
    Sound.OSC.Transport.FD.TCP Sound.OSC.Transport.FD.UDP
    Sound.OSC.Transport.Monad Sound.OSC.Wait

import-dirs:          /usr/lib/ghc-8.10.5/site-local/hosc-0.19
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hosc-0.19
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hosc
hs-libraries:         HShosc-0.19-9E4zMGa8TwZKXIyTOOXEfd
depends:
    base-4.14.2.0 binary-0.8.8.0
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB bytestring-0.10.12.0
    data-binary-ieee754-0.4.4-BBofvLKootn8l57SJnz736
    network-3.1.2.2-5EE9GqQpTmvH0oBl8byO4M time-1.9.3
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hosc/html/hosc.haddock
haddock-html:         /usr/share/doc/haskell-hosc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

